# Maintainers

This document lists the Maintainers of the Project. Maintainers may be added once approved by the existing maintainers as described in the [Governance document](./GOVERNANCE.md). By adding your name to this list you are agreeing to abide by the Project governance documents and to abide by all of the Organization's polices, including the [code of conduct](./CODE-OF-CONDUCT.md), [trademark policy](./TRADEMARKS.md), and [antitrust policy](./ANTITRUST.md). If you are participating because of your affiliation with another organization (designated below), you represent that you have the authority to bind that organization to these policies.

| **NAME** | **Handle** |
| --- | --- |
| Huigang Chen | @huigangchen |
| Totte Harinen | @t-tte |
| Jeong-Yoon Lee | @jeongyoonlee |
| Paul Lo | @paullo0106 |
| Jing Pan | @ppstacy |
| Alexander Popkov | @@alexander-pv |
| Roland Stevenson | @ras44 |
| Yifeng Wu | @vincewu51 |
| Zhenyu Zhao | @zhenyuz0500 |

## Previous Maintainers

| **NAME** | **Handle** |
| --- | --- |
| Mike Yung | @yungmsh |
| Yuchen Luo | @yluogit |
| Steve Yang | @steveyang90 |

---
Adapted from [MVG-0.1-beta](https://github.com/github/MVG/tree/v0.1-beta).
Made with love by GitHub. Licensed under the [CC-BY 4.0 License](https://creativecommons.org/licenses/by-sa/4.0/).
